@@ -17,11 +17,13 @@ __all__ = [
     "GeneralizedTTA",
     "MultiscaleTTA",
     "d2_image_augment",
+    "d2_labels_augment",
     "d2_image_deaugment",
     "d2_labels_deaugment",
     "d4_image2label",
     "d4_image2mask",
     "d4_image_augment",
+    "d4_labels_augment",
     "d4_image_deaugment",
     "d4_labels_deaugment",
     "fivecrop_image2label",
@@ -30,12 +32,18 @@ __all__ = [
     "fliplr_image2label",
     "fliplr_image2mask",
     "fliplr_image_augment",
+    "fliplr_labels_augment",
     "fliplr_image_deaugment",
     "fliplr_labels_deaugment",
     "flips_image_augment",
+    "flips_labels_augment",
     "flips_image_deaugment",
     "flips_labels_deaugment",
+    "flipud_image_augment",
+    "flipud_image_deaugment",
+    "flipud_labels_deaugment",
     "ms_image_augment",
+    "ms_labels_augment",
     "ms_image_deaugment",
     "tencrop_image2label",
 ]
@@ -45,8 +53,9 @@ MaybeStrOrCallable = Optional[Union[str, Callable]]
 
 def _deaugment_averaging(x: Tensor, reduction: MaybeStrOrCallable) -> Tensor:
     """
-    Helper method to average predictions of TTA-ed model.
+    Average predictions of TTA-ed model.
     This function assumes TTA dimension is 0, e.g [T, B, C, Ci, Cj, ..]
+
     Args:
         x: Input tensor of shape [T, B, ... ]
         reduction: Reduction mode ("sum", "mean", "gmean", "hmean", function, None)
@@ -99,7 +108,10 @@ def fivecrop_image_augment(image: Tensor, crop_size: Tuple[int, int]) -> Tensor:
     center_crop_x = (image_width - crop_width) // 2
     crop_cc = image[..., center_crop_y : center_crop_y + crop_height, center_crop_x : center_crop_x + crop_width]
 
-    return torch.cat([crop_tl, crop_tr, crop_bl, crop_br, crop_cc], dim=0,)
+    return torch.cat(
+        [crop_tl, crop_tr, crop_bl, crop_br, crop_cc],
+        dim=0,
+    )
 
 
 def fivecrop_label_deaugment(logits: Tensor, reduction: MaybeStrOrCallable = "mean") -> Tensor:
@@ -236,13 +248,28 @@ def fliplr_image_augment(image: Tensor) -> Tensor:
 
     Returns:
         Tensor of [B * 2, C, H, W] shape with:
-            - Original tensor rotated by 180 degrees
-            - Horisonalty-flipped tensor
+            - Original tensor
+            - Horizontally-flipped tensor
 
     """
     return torch.cat([image, F.torch_fliplr(image)], dim=0)
 
 
+def flipud_image_augment(image: Tensor) -> Tensor:
+    """
+    Augment input tensor using flip from up to bottom
+    Args:
+        image: Tensor of [B,C,H,W] shape
+
+    Returns:
+        Tensor of [B * 2, C, H, W] shape with:
+            - Original tensor
+            - Vertically-flipped tensor
+
+    """
+    return torch.cat([image, F.torch_flipud(image)], dim=0)
+
+
 def fliplr_image_deaugment(image: Tensor, reduction: MaybeStrOrCallable = "mean") -> Tensor:
     """
     Deaugment input tensor (output of the model) assuming the input was fliplr-augmented image (See fliplr_image_augment).
@@ -257,9 +284,25 @@ def fliplr_image_deaugment(image: Tensor, reduction: MaybeStrOrCallable = "mean"
     assert image.size(0) % 2 == 0
 
     b1, b2 = torch.chunk(image, 2)
-
     image: Tensor = torch.stack([b1, F.torch_fliplr(b2)])
+    return _deaugment_averaging(image, reduction=reduction)
 
+
+def flipud_image_deaugment(image: Tensor, reduction: MaybeStrOrCallable = "mean") -> Tensor:
+    """
+    Deaugment input tensor (output of the model) assuming the input was flipud-augmented image (See flipud_image_augment).
+    Args:
+        image: Tensor of [B * 2, C, H, W] shape
+        reduction: Reduction model for aggregating outputs. Default is taking mean.
+
+    Returns:
+        Tensor of [B, C, H, W] shape if reduction is not None or "none", otherwise returns de-augmented tensor of
+        [2, B, C, H, W] shape
+    """
+    assert image.size(0) % 2 == 0
+
+    b1, b2 = torch.chunk(image, 2)
+    image: Tensor = torch.stack([b1, F.torch_flipud(b2)])
     return _deaugment_averaging(image, reduction=reduction)
 
 
@@ -277,7 +320,15 @@ def d2_image_augment(image: Tensor) -> Tensor:
             - Vertically-flipped tensor
 
     """
-    return torch.cat([image, F.torch_rot180(image), F.torch_fliplr(image), F.torch_flipud(image),], dim=0,)
+    return torch.cat(
+        [
+            image,
+            F.torch_rot180(image),
+            F.torch_fliplr(image),
+            F.torch_flipud(image),
+        ],
+        dim=0,
+    )
 
 
 def d2_image_deaugment(image: Tensor, reduction: MaybeStrOrCallable = "mean") -> Tensor:
@@ -296,7 +347,12 @@ def d2_image_deaugment(image: Tensor, reduction: MaybeStrOrCallable = "mean") ->
     b1, b2, b3, b4 = torch.chunk(image, 4)
 
     image: Tensor = torch.stack(
-        [b1, F.torch_rot180(b2), F.torch_fliplr(b3), F.torch_flipud(b4),]
+        [
+            b1,
+            F.torch_rot180(b2),
+            F.torch_fliplr(b3),
+            F.torch_flipud(b4),
+        ]
     )
 
     return _deaugment_averaging(image, reduction=reduction)
@@ -339,11 +395,12 @@ def d4_image_augment(image: Tensor) -> Tensor:
             - Transposed tensor rotated by 180 degrees
 
     """
-    if image.size(2) != image.size(3):
-        raise ValueError(
-            f"Input tensor must have number of rows equal to number of cols. "
-            f"Got input tensor of shape {image.size()}"
-        )
+    if not torch.jit.is_scripting() and not torch.jit.is_tracing():
+        if image.size(2) != image.size(3):
+            raise ValueError(
+                f"Input tensor must have number of rows equal to number of cols. Got input tensor of shape {image.size()}"
+            )
+
     image_t = F.torch_transpose(image)
     return torch.cat(
         [
@@ -372,7 +429,7 @@ def d4_labels_deaugment(image: Tensor, reduction: MaybeStrOrCallable = "mean") -
         [8, B, C] shape
     """
     if image.size(0) % 8 != 0:
-        raise RuntimeError("Batch size must be divisable by 8")
+        raise RuntimeError("Batch size must be divisible by 8")
 
     b1, b2, b3, b4, b5, b6, b7, b8 = torch.chunk(image, 8)
     image: Tensor = torch.stack([b1, b2, b3, b4, b5, b7, b7, b8])
@@ -385,15 +442,16 @@ def d4_image_deaugment(image: Tensor, reduction: MaybeStrOrCallable = "mean") ->
     Deaugment input tensor (output of the model) assuming the input was D4-augmented image (See d4_augment).
     Args:
         image: Tensor of [B * 8, C, H, W] shape
-        average: If True performs averaging of 8 outputs, otherwise - summation.
+        reduction: Reduction model for aggregating outputs. Default is taking mean.
 
     Returns:
         Tensor of [B, C, H, W] shape if reduction is not None or "none", otherwise returns de-augmented tensor of
         [4, B, C, H, W] shape
 
     """
-    if image.size(0) % 8 != 0:
-        raise RuntimeError("Batch size must be divisable by 8")
+    if not torch.jit.is_scripting() and not torch.jit.is_tracing():
+        if image.size(0) % 8 != 0:
+            raise RuntimeError("Batch size must be divisible by 8")
 
     b1, b2, b3, b4, b5, b6, b7, b8 = torch.chunk(image, 8)
 
@@ -429,7 +487,26 @@ def flips_image_augment(image: Tensor) -> Tensor:
     return torch.cat([image, F.torch_fliplr(image), F.torch_flipud(image)], dim=0)
 
 
-def flips_image_deaugment(image: Tensor, reduction: MaybeStrOrCallable = "mean",) -> Tensor:
+def fliplr_labels_augment(labels: Tensor) -> Tensor:
+    return torch.cat([labels, labels], dim=0)
+
+
+def flips_labels_augment(labels: Tensor) -> Tensor:
+    return torch.cat([labels, labels, labels], dim=0)
+
+
+def d2_labels_augment(labels: Tensor) -> Tensor:
+    return torch.cat([labels, labels, labels, labels], dim=0)
+
+
+def d4_labels_augment(labels: Tensor) -> Tensor:
+    return torch.cat([labels, labels, labels, labels, labels, labels, labels, labels], dim=0)
+
+
+def flips_image_deaugment(
+    image: Tensor,
+    reduction: MaybeStrOrCallable = "mean",
+) -> Tensor:
     """
     Deaugment input tensor (output of the model) assuming the input was flip-augmented image (See flips_augment).
     Args:
@@ -450,25 +527,52 @@ def flips_image_deaugment(image: Tensor, reduction: MaybeStrOrCallable = "mean",
     return _deaugment_averaging(image, reduction=reduction)
 
 
-def fliplr_labels_deaugment(logits: Tensor, reduction: MaybeStrOrCallable = "mean",) -> Tensor:
+def fliplr_labels_deaugment(
+    logits: Tensor,
+    reduction: MaybeStrOrCallable = "mean",
+) -> Tensor:
     """
     Deaugment input tensor (output of the model) assuming the input was fliplr-augmented image (See fliplr_image_augment).
     Args:
         logits: Tensor of [B * 2, C] shape
-        reduction: If True performs averaging of 3 outputs, otherwise - summation.
+        reduction: If True performs averaging of 2 outputs, otherwise - summation.
 
     Returns:
         Tensor of [B, C, H, W] shape.
     """
     if logits.size(0) % 2 != 0:
-        raise RuntimeError("Batch size must be divisable by 2")
+        raise RuntimeError("Batch size must be divisible by 2")
 
     orig, flipped_lr = torch.chunk(logits, 2)
     logits: Tensor = torch.stack([orig, flipped_lr])
     return _deaugment_averaging(logits, reduction=reduction)
 
 
-def flips_labels_deaugment(logits: Tensor, reduction: MaybeStrOrCallable = "mean",) -> Tensor:
+def flipud_labels_deaugment(
+    logits: Tensor,
+    reduction: MaybeStrOrCallable = "mean",
+) -> Tensor:
+    """
+    Deaugment input tensor (output of the model) assuming the input was flipud-augmented image (See flipud_image_augment).
+    Args:
+        logits: Tensor of [B * 2, C] shape
+        reduction: If True performs averaging of 2 outputs, otherwise - summation.
+
+    Returns:
+        Tensor of [B, C, H, W] shape.
+    """
+    if logits.size(0) % 2 != 0:
+        raise RuntimeError("Batch size must be divisible by 2")
+
+    orig, flipped_ud = torch.chunk(logits, 2)
+    logits: Tensor = torch.stack([orig, flipped_ud])
+    return _deaugment_averaging(logits, reduction=reduction)
+
+
+def flips_labels_deaugment(
+    logits: Tensor,
+    reduction: MaybeStrOrCallable = "mean",
+) -> Tensor:
     """
     Deaugment input tensor (output of the model) assuming the input was flip-augmented image (See flips_image_augment).
     Args:
@@ -479,7 +583,7 @@ def flips_labels_deaugment(logits: Tensor, reduction: MaybeStrOrCallable = "mean
         Tensor of [B, C, H, W] shape.
     """
     if logits.size(0) % 3 != 0:
-        raise RuntimeError("Batch size must be divisable by 3")
+        raise RuntimeError("Batch size must be divisible by 3")
 
     orig, flipped_lr, flipped_ud = torch.chunk(logits, 3)
     logits: Tensor = torch.stack([orig, flipped_lr, flipped_ud])
@@ -497,6 +601,10 @@ class TTAWrapper(nn.Module):
         return self.tta(self.model, *input)
 
 
+def ms_labels_augment(labels: Tensor, size_offsets: List[Union[int, Tuple[int, int]]]) -> List[Tensor]:
+    return [labels] * len(size_offsets)
+
+
 def ms_image_augment(
     image: Tensor, size_offsets: List[Union[int, Tuple[int, int]]], mode="bilinear", align_corners=False
 ) -> List[Tensor]:
@@ -523,18 +631,18 @@ def ms_image_augment(
 
 
 def ms_labels_deaugment(
-    logits: List[Tensor], size_offsets: List[Union[int, Tuple[int, int]]], reduction: MaybeStrOrCallable = "mean",
+    logits: List[Tensor],
+    size_offsets: List[Union[int, Tuple[int, int]]],
+    reduction: MaybeStrOrCallable = "mean",
 ):
     """
-    Deaugment logits
+    Deaugment multi-scale label predictions.
+    This function does not apply interpolation, since the outputs are expected to be scalar or 1d vector.
 
     Args:
         logits: List of tensors of shape [B, C]
-        size_offsets:
+        size_offsets: Not used
         reduction:
-
-    Returns:
-
     """
     if len(logits) != len(size_offsets):
         raise ValueError("Number of images must be equal to number of size offsets")
@@ -552,6 +660,7 @@ def ms_image_deaugment(
     stride: int = 1,
 ) -> Tensor:
     """
+    Perform multi-scale deaugmentation of predicted feature maps.
 
     Args:
         images: List of tensors of shape [B, C, Hi, Wi], [B, C, Hj, Wj], [B, C, Hk, Wk]
@@ -563,7 +672,7 @@ def ms_image_deaugment(
         Used to correctly scale size_offsets to match with size of output feature maps
 
     Returns:
-
+        Averaged feature-map of the original size
     """
     if len(images) != len(size_offsets):
         raise ValueError("Number of images must be equal to number of size offsets")
@@ -590,6 +699,8 @@ def ms_image_deaugment(
 
 
 class GeneralizedTTA(nn.Module):
+    __slots__ = ["augment_fn", "deaugment_fn"]
+
     """
     Example:
         tta_model = GeneralizedTTA(model,
@@ -619,10 +730,10 @@ class GeneralizedTTA(nn.Module):
         # Augment & forward
         if isinstance(self.augment_fn, dict):
             if len(input) != 0:
-                raise ValueError("Input for GeneralizedTTA must be exactly one tensor")
-            augmented_inputs = dict(
-                (key, augment(value)) for (key, value), augment in zip(kwargs.items(), self.augment_fn)
-            )
+                raise ValueError(
+                    "Input for GeneralizedTTA must not have positional arguments when augment_fn is dictionary"
+                )
+            augmented_inputs = dict((key, augment(kwargs[key])) for (key, augment) in self.augment_fn.items())
             outputs = self.model(**augmented_inputs)
         elif isinstance(self.augment_fn, (list, tuple)):
             if len(kwargs) != 0:
