@@ -1,9 +1,11 @@
 from __future__ import absolute_import
 
+from .balanced_bce import *
 from .bitempered_loss import *
 from .dice import *
 from .focal import *
 from .focal_cosine import *
+from .functional import *
 from .jaccard import *
 from .joint_loss import *
 from .lovasz import *
