@@ -65,6 +65,8 @@ ACT_SWISH_NAIVE = "swish_naive"
 
 # This version reduces memory overhead of Swish during training by
 # recomputing torch.sigmoid(x) in backward instead of saving it.
+
+
 @torch.jit.script
 def swish_jit_fwd(x):
     return x.mul(torch.sigmoid(x))
@@ -251,7 +253,7 @@ def get_activation_block(activation_name: str):
         ACT_SOFTPLUS: nn.Softplus,
         ACT_SWISH: Swish,
         ACT_SWISH_NAIVE: SwishNaive,
-        ACT_SIGMOID: nn.Sigmoid
+        ACT_SIGMOID: nn.Sigmoid,
     }
 
     return ACTIVATIONS[activation_name.lower()]
@@ -268,6 +270,9 @@ def instantiate_activation_block(activation_name: str, **kwargs) -> nn.Module:
     if "slope" in kwargs and activation_name in {ACT_LEAKY_RELU}:
         act_params["negative_slope"] = kwargs["slope"]
 
+    if activation_name == ACT_PRELU:
+        act_params["num_parameters"] = kwargs["num_parameters"]
+
     return block(**act_params)
 
 
