@@ -3,9 +3,6 @@
 Original paper: https://arxiv.org/abs/1411.5752
 """
 
-import torch
-from torch import nn
-from torch.nn import functional as F
 from .fpn import FPNFuse
 
 __all__ = ["HyperColumn"]
